@@ -76,9 +76,9 @@ class Application(Model):
 
 
 STATUS_CHOICES = [
-    ('Todo', _('Todo')),
-    ('Done', _('Done')),
-    ('Failed', _('Failed')),
+    ("Todo", _("Todo")),
+    ("Done", _("Done")),
+    ("Failed", _("Failed")),
 ]
 
 
@@ -91,11 +91,15 @@ class Deployment(Model):
         blank=True,
     )
     date = models.DateTimeField(auto_now_add=True)
-    status = models.CharField(max_length=8, choices=STATUS_CHOICES, default='Todo', null=True, blank=True)
+    status = models.CharField(
+        max_length=8, choices=STATUS_CHOICES, default="Todo", null=True, blank=True
+    )
 
     def __str__(self):
         try:
-            return "{} - {} ({})".format(self.date, self.application.friendly_name, self.application.urlid)
+            return "{} - {} ({})".format(
+                self.date, self.application.friendly_name, self.application.urlid
+            )
         except:
             return self.urlid
 
@@ -235,7 +239,9 @@ class ApplicationComponentParameter(Model):
     def __str__(self):
         try:
             return "{} -> {} ({})".format(
-                self.component.application.friendly_name, self.component.component.friendly_name, self.urlid
+                self.component.application.friendly_name,
+                self.component.component.friendly_name,
+                self.urlid,
             )
         except:
             return self.urlid
@@ -325,7 +331,9 @@ class ApplicationPackageParameter(Model):
     def __str__(self):
         try:
             return "{} -> {} ({})".format(
-                self.package.application.friendly_name, self.package.package.friendly_name, self.urlid
+                self.package.application.friendly_name,
+                self.package.package.friendly_name,
+                self.urlid,
             )
         except:
             return self.urlid
@@ -367,7 +375,9 @@ class ComponentExtension(Model):
     def __str__(self):
         try:
             return "{} + {} ({})".format(
-                self.base_component.application.friendly_name, self.component.friendly_name, self.urlid
+                self.base_component.application.friendly_name,
+                self.component.friendly_name,
+                self.urlid,
             )
         except:
             return self.urlid
@@ -415,7 +425,9 @@ class ComponentExtensionParameter(Model):
     def __str__(self):
         try:
             return "{} -> {} ({})".format(
-                self.component.base_component.application.friendly_name, self.component.component.friendly_name, self.urlid
+                self.component.base_component.application.friendly_name,
+                self.component.component.friendly_name,
+                self.urlid,
             )
         except:
             return self.urlid
