@@ -50,7 +50,12 @@ class ApplicationDetailSerializer(serializers.HyperlinkedModelSerializer):
 
         for applicationComponent in application["components"]:
             component = Component.objects.get(id=applicationComponent.obj.component_id)
-            insertComponent = {"type": component.name, "route": False, "parameters": []}
+            insertComponent = {
+                "type": component.name,
+                "route": False,
+                "parameters": [],
+                "extensions": [],
+            }
             keys = []
             for parameter in applicationComponent.obj.parameters.all():
                 if parameter.key == "route":
@@ -68,6 +73,31 @@ class ApplicationDetailSerializer(serializers.HyperlinkedModelSerializer):
                         i = {}
                         i[parameter.key] = format(parameter.default)
                         insertComponent["parameters"].append(i)
+            for extensionComponent in applicationComponent.obj.extensions.all():
+                extension = Component.objects.get(id=extensionComponent.component_id)
+                componentExtension = {
+                    "type": extension.name,
+                    "route": False,
+                    "parameters": [],
+                }
+                keys = []
+                for parameter in extensionComponent.parameters.all():
+                    if parameter.key == "route":
+                        componentExtension["route"] = format(parameter.value)
+                    else:
+                        i = {}
+                        i[parameter.key] = format(parameter.value)
+                        componentExtension["parameters"].append(i)
+                    keys.append(parameter.key)
+                for parameter in extension.parameters.all():
+                    if not parameter.key in keys:
+                        if parameter.key == "route":
+                            componentExtension["route"] = format(parameter.default)
+                        else:
+                            i = {}
+                            i[parameter.key] = format(parameter.default)
+                            componentExtension["parameters"].append(i)
+                insertComponent["extensions"].append(componentExtension)
             serialized["apps"]["hosts"][application["slug"]]["components"].append(
                 insertComponent
             )
